<?php

namespace Modules\Cotacao\Modules\Pedido\Services;

use Doctrine\ORM\EntityManager;
use \Zeedhi\Framework\DB\StoredProcedure\StoredProcedure;
use \Zeedhi\Framework\DB\StoredProcedure\Param;
use Teknisa\Libs\Util\Utilities;
use Exception;

class Sup09400DadosDoFornecedorEcommerceService extends \Teknisa\GER\Services\CryptService
{
    protected $entityManager;
    protected $connection;
    protected $newCodeSC;
    protected $environment;

    public function __construct(EntityManager $entityManager, $connection, $newCodeSC, $environment)
    {
        $this->entityManager = $entityManager;
        $this->connection    = $connection;
        $this->newCodeSC     = $newCodeSC;
        $this->environment   = $environment;
    }

    public function beginTransaction()
    {
        $this->connection->beginTransaction();
    }

    public function commit()
    {
        $this->connection->commit();
    }

    public function rollback()
    {
        $this->connection->rollback();
    }

    public function getPCsNaoLidas($row)
    {
        $query =  $this->connection->prepare(
            "SELECT 
                PC.CDFORNECED,
                PC.CDFILIAL,
                PCG.NRPEDIDOCOL,
                TO_CHAR(PCG.DTEXPIRAPEDCOL, 'DD/MM/YYYY') DTEXPIRAPEDCOL,
                TO_CHAR(PCG.DTINIPERGERAL, 'DD/MM/YYYY') DTINIPERGERAL,
                TO_CHAR(PCG.DTFINPERGERAL, 'DD/MM/YYYY') DTFINPERGERAL,
                FI.CDFILIAL,
                FI.CDFILIAL || ' ' || FI.NMFILIAL NMFILIAL,
                FO.NMRAZSOCFORN,
                OP.NMOPERADOR
            FROM 
                PEDCOLETA PC,
                PEDCOLGERAL PCG,
                FILIAL FI,
                FORNECEDOR FO,
                OPERADOR OP
            WHERE
                PCG.CDFILIAL = FI.CDFILIAL 
                AND PCG.NRORG = FI.NRORG 
                AND PCG.NRPEDIDOCOL = PC.NRPEDIDOCOL
                AND PC.IDSITUPEDCOL = 'N'
                AND PCG.IDATIVO = 'S'
                AND PCG.DTEXPIRAPEDCOL BETWEEN TRUNC(SYSDATE) AND TRUNC(SYSDATE) + :P_NRDIASANTESNOTIFIC
                AND PCG.NRORG = :P_NRORG
                AND FO.CDFORNECED = PC.CDFORNECED
                AND OP.CDOPERADOR = PC.CDOPERADOR
            GROUP BY
                PC.CDFORNECED,
                PC.CDFILIAL,
                PCG.NRPEDIDOCOL,
                PCG.DTEXPIRAPEDCOL,
                PCG.DTINIPERGERAL,
                PCG.DTFINPERGERAL,
                FI.CDFILIAL,
                FI.NMFILIAL,
                FO.NMRAZSOCFORN,
                OP.NMOPERADOR
            ORDER BY
                PC.CDFORNECED,
                PCG.DTEXPIRAPEDCOL,
                PC.CDFILIAL,
                PCG.NRPEDIDOCOL"
        );

        $query->execute(array(
            "P_NRORG" => $row['P_NRORG'],
            "P_NRDIASANTESNOTIFIC" => $row['P_NRDIASANTESNOTIFIC']
        ));

        $dataSet = $query->fetchAll();

        return $dataSet;
    }

    public function getAFsNaoLidas($row)
    {
        $query =  $this->connection->prepare(
            "SELECT 
            	A.CDFORNECED, 
            	F.CDFILIAL,
            	F.CDFILIAL || ' ' || F.NMFILIAL NMFILIAL,
            	O.NMRAZSOCFORN,
            	A.NRSEQAPURAF,
            	A.NRSEQENVIOAFORN,
            	A.NRAUTOFORN,
            	TO_CHAR(A.DTAUTOFORN,'DD/MM/YYYY') DTAUTOFORN,
            	TO_CHAR(MAX(I.DTPROGENTAF),'DD/MM/YYYY') DTENTREGAFFORN,
            	A.VRTOTALAF,
            	A.NRORG
            FROM 
            	AUTOFORNE A 
            	INNER JOIN ITEMAUTF I ON 
            		A.CDFILLANC = I.CDFILLANC
            		AND A.CDFILDEST  = I.CDFILDEST
            		AND A.NRAUTOFORN = I.NRAUTOFORN
            		AND A.NRORG      = I.NRORG
            	LEFT JOIN LOGDOWNLOADAF L ON 
            		A.CDFORNECED = L.CDFORNECED
            		AND A.NRAUTOFORN = L.NRAUTOFORN
            		AND A.CDFILDEST  = L.CDFILDEST
            		AND A.CDFILLANC  = L.CDFILLANC
            		AND A.NRSEQENVIOAFORN = L.NRSEQENVIOAFORN
            		AND A.NRORG = L.NRORG
            	INNER JOIN FILIAL F ON 
            		A.CDFILDEST = F.CDFILIAL
            		AND A.NRORG = F.NRORG
            	INNER JOIN FORNECEDOR O ON 
            		O.CDFORNECED = A.CDFORNECED
            		AND A.NRORG = O.NRORG
            WHERE 
            	I.DTPROGENTAF BETWEEN TRUNC(SYSDATE) AND TRUNC(SYSDATE) + :P_NRDIASANTESNOTIFIC
            	AND NVL(L.NRSEQENVIOAFORN,'N') = 'N'
            	AND I.NRORG = :P_NRORG
            	AND A.NRSEQENVIOAFORN IS NOT NULL
            GROUP BY 
            	A.CDFORNECED, 
            	F.CDFILIAL,
            	F.CDFILIAL || ' ' || F.NMFILIAL,
            	O.NMRAZSOCFORN, 
            	A.NRSEQAPURAF, 
            	A.NRSEQENVIOAFORN, 
            	A.NRAUTOFORN,
            	TO_CHAR(A.DTAUTOFORN,'DD/MM/YYYY'),
                I.DTPROGENTAF,
            	A.VRTOTALAF, 
            	A.NRORG
            ORDER BY 
            	A.CDFORNECED, 
            	I.DTPROGENTAF,  
            	F.CDFILIAL, 
            	A.NRAUTOFORN"
        );

        $query->execute(array(
            "P_NRORG" => $row['P_NRORG'],
            "P_NRDIASANTESNOTIFIC" => $row['P_NRDIASANTESNOTIFIC']
        ));

        $dataSet = $query->fetchAll();

        return $dataSet;
    }

    public function retornaParamgeral()
    {
        $query =  $this->connection->prepare(
            "SELECT IDSISDOS FROM PARAMGERAL"
        );

        $query->execute();

        $paramGeral = $query->fetchAll();

        return $paramGeral[0];
    }

    public function getParametrosGerais($cdFilial)
    {
        $query =  $this->connection->prepare(
            "SELECT 
                PARAMGERALECOMMERCE.CDFILIAL, 
                PARAMGERALECOMMERCE.DSLINKFALECONOSCO, 
                PARAMGERALECOMMERCE.DSLINKAUXILIAR, 
                PARAMGERALECOMMERCE.DSNOMELINKAUX, 
                PARAMGERALECOMMERCE.DSLINKECOMMERCE,
                PARAMGERALECOMMERCE.IDEXIBEQTDCMP,
                PARAMGERALECOMMERCE.IDGRAVAITEMZERADO,
                PARAMGERALECOMMERCE.IDCOTUNICAPEDCOL,
                PARAMGERALECOMMERCE.TXMSGFORNECEDOR,
                PARAMGERALECOMMERCE.IDUTLAPROVMASSA,
                PARAMGERALECOMMERCE.IDFILIALPADRAOSMTP,
                EMPRESA.CDEMPRESA, 
                EMPRESA.NMEMPRESA
            FROM 
                PARAMGERALECOMMERCE, 
                EMPRESA, 
                FILIAL
            WHERE 
                PARAMGERALECOMMERCE.CDEMPRESA = EMPRESA.CDEMPRESA 
                AND PARAMGERALECOMMERCE.CDFILIAL = NVL(FILIAL.CDFILCENTCMP, FILIAL.CDFILIAL)
                AND FILIAL.CDFILIAL = :P_CDFILIAL"
        );

        $query->execute(
            array(
                "P_CDFILIAL" => $cdFilial
            )
        );

        $dataSet = $query->fetchAll();

        return $dataSet;
    }

    public function checkNotificacaoExists($row)
    {
        $query =  $this->connection->prepare(
            "SELECT 
                IDTPNOTIFIC
             FROM 
                PARAMNOTIFICECO
             WHERE
                IDTPNOTIFIC = :P_IDTPNOTIFIC AND
                NRORG = :P_NRORG AND
                CDFILIAL = :P_CDFILIAL"
        );

        $query->execute(array(
            "P_IDTPNOTIFIC"  => $row['IDTPNOTIFIC'],
            "P_NRORG"        => $row['NRORG'],
            "P_CDFILIAL"     => $row['CDFILIAL']
        ));

        $dataSet = $query->fetchAll();

        return $dataSet;
    }

    public function getDadosNotificacao($row)
    {
        $query =  $this->connection->prepare(
            "SELECT 
                IDTPNOTIFIC, 
                IDENVIANOTIFIC, 
                NRDIASANTESNOTIFIC,
                TXEMAILNOTIFIC, 
                NRORG, 
                CDFILIAL
             FROM 
                PARAMNOTIFICECO
             WHERE
                NRORG = :P_NRORG AND
                CDFILIAL = :P_CDFILIAL"
        );

        $query->execute(array(
            "P_NRORG"        => $row['NRORG'],
            "P_CDFILIAL"     => $row['CDFILIAL']
        ));

        $dataSet = $query->fetchAll();

        return $dataSet;
    }

    public function saveNotificacoesEcommerce($row)
    {
        $result = $this->checkNotificacaoExists($row);

        if (sizeof($result) === 0) {
            $query = $this->entityManager->getConnection()->prepare(
                "INSERT INTO PARAMNOTIFICECO 
                (
                    IDTPNOTIFIC, IDENVIANOTIFIC, NRDIASANTESNOTIFIC,
                    TXEMAILNOTIFIC, NRORG, CDFILIAL
                )
                VALUES
                (
                    :P_IDTPNOTIFIC, :P_IDENVIANOTIFIC, :P_NRDIASANTESNOTIFIC,
                    :P_TXEMAILNOTIFIC, :P_NRORG, :P_CDFILIAL
                )"
            );

            $query->execute(array(
                "P_IDTPNOTIFIC"        => $row['IDTPNOTIFIC'],
                "P_IDENVIANOTIFIC"     => $row["IDENVIANOTIFIC"],
                "P_NRDIASANTESNOTIFIC" => $row["NRDIASANTESNOTIFIC"],
                "P_TXEMAILNOTIFIC"     => $row["TXEMAILNOTIFIC"],
                "P_NRORG"              => $row['NRORG'],
                "P_CDFILIAL"           => $row['CDFILIAL']
            ));

            $dataSet = 1;
        } else {
            $sql =  "UPDATE
                        PARAMNOTIFICECO
                    SET
                        IDENVIANOTIFIC = :P_IDENVIANOTIFIC,
                        NRDIASANTESNOTIFIC = :P_NRDIASANTESNOTIFIC,
                        TXEMAILNOTIFIC = :P_TXEMAILNOTIFIC
                    WHERE
                        IDTPNOTIFIC = :P_IDTPNOTIFIC AND
                        NRORG = :P_NRORG AND
                        CDFILIAL = :P_CDFILIAL";

            $params = array(
                "P_IDENVIANOTIFIC"     => $row["IDENVIANOTIFIC"],
                "P_NRDIASANTESNOTIFIC" => $row["NRDIASANTESNOTIFIC"],
                "P_TXEMAILNOTIFIC"     => $row["TXEMAILNOTIFIC"],
                "P_IDTPNOTIFIC"        => $row['IDTPNOTIFIC'],
                "P_NRORG"              => $this->environment->getNrOrgTrab(),
                "P_CDFILIAL"           => $row['CDFILIAL']
            );

            $dataSet = $this->entityManager->getConnection()->executeUpdate($sql, $params);
        }

        return $dataSet;
    }

    public function deleteNotificacoesEcommerce($row)
    {
        $query = $this->entityManager->getConnection()->prepare(
            "DELETE FROM 
                    PARAMNOTIFICECO 
                WHERE 
                    IDTPNOTIFIC = :P_IDTPNOTIFIC AND
                    NRORG = :P_NRORG AND
                    CDFILIAL = :P_CDFILIAL"
        );

        $query->execute(array(
            "P_IDTPNOTIFIC"  => $row['IDTPNOTIFIC'],
            "P_NRORG"        => $this->environment->getNrOrgTrab(),
            "P_CDFILIAL"     => $row['CDFILIAL']
        ));
    }

    public function retornaCentralCompras($row)
    {
        $sql = "SELECT NVL(FILIAL.CDFILCENTCMP, FILIAL.CDFILIAL) AS CDFILCENTCMP FROM FILIAL WHERE FILIAL.CDFILIAL = :CDFILIAL AND FILIAL.NRORG = :NRORG";

        $params = [
            "CDFILIAL" => $row['CDFILIAL'],
            "NRORG" => $this->environment->getNrOrgTrab()
        ];

        $query = $this->connection->prepare($sql);
        $query->execute($params);
        $cdfilial = $query->fetchAll();

        return $cdfilial[0]['CDFILCENTCMP'];
    }

    public function saveParametrosGerais($row, $centralCompras)
    {
        $query = $this->entityManager->getConnection()->prepare("SELECT * FROM PARAMGERALECOMMERCE WHERE CDFILIAL = :CDFILIAL AND NRORG  = :NRORG");

        $params = [
            "CDFILIAL" => $centralCompras,
            "NRORG" => $this->environment->getNrOrgTrab()
        ];

        $query->execute($params);
        $result = $query->fetchAll();
        if (sizeof($result) === 0) {
            $query = $this->entityManager->getConnection()->prepare(
                "INSERT INTO PARAMGERALECOMMERCE
               (DSLINKFALECONOSCO,
                DSLINKAUXILIAR,
                DSNOMELINKAUX,
                DSLINKECOMMERCE,
                IDEXIBEQTDCMP,
                CDEMPRESA,
                IDGRAVAITEMZERADO,
                IDCOTUNICAPEDCOL,
                TXMSGFORNECEDOR,
                IDUTLAPROVMASSA,
                IDFILIALPADRAOSMTP,
                CDFILIAL)
            VALUES 
               (:DSLINKFALECONOSCO,
                :DSLINKAUXILIAR,
                :DSNOMELINKAUX,
                :DSLINKECOMMERCE,
                :IDEXIBEQTDCMP,
                :CDEMPRESA,
                :IDGRAVAITEMZERADO,
                :IDCOTUNICAPEDCOL,
                :TXMSGFORNECEDOR,
                :IDUTLAPROVMASSA,
                :IDFILIALPADRAOSMTP,
                :CDFILIAL)"
            );

            $query->execute(
                array(
                    "DSLINKFALECONOSCO" => $row["DSLINKFALECONOSCO"],
                    "DSLINKAUXILIAR"    => $row["DSLINKAUXILIAR"],
                    "DSNOMELINKAUX"     => $row["DSNOMELINKAUX"],
                    "DSLINKECOMMERCE"   => $row['DSLINKECOMMERCE'],
                    "IDEXIBEQTDCMP"     => $row["IDEXIBEQTDCMP"],
                    "CDEMPRESA"         => $row["CDEMPRESA"],
                    "IDGRAVAITEMZERADO" => $row["IDGRAVAITEMZERADO"],
                    "IDCOTUNICAPEDCOL"  => $row["IDCOTUNICAPEDCOL"],
                    "TXMSGFORNECEDOR"   => $row["TXMSGFORNECEDOR"],
                    "IDUTLAPROVMASSA"   => $row["IDUTLAPROVMASSA"],
                    "IDFILIALPADRAOSMTP" => $row["IDFILIALPADRAOSMTP"],
                    "CDFILIAL"          => $centralCompras
                )
            );

            $dataSet = 1;
        } else {
            $sql =
                "UPDATE PARAMGERALECOMMERCE
                    SET DSLINKFALECONOSCO   = :DSLINKFALECONOSCO,
                        DSLINKAUXILIAR      = :DSLINKAUXILIAR,
                        DSNOMELINKAUX       = :DSNOMELINKAUX,
                        DSLINKECOMMERCE     = :DSLINKECOMMERCE,
                        IDEXIBEQTDCMP       = :IDEXIBEQTDCMP,
                        CDEMPRESA           = :CDEMPRESA,
                        IDGRAVAITEMZERADO   = :IDGRAVAITEMZERADO,
                        TXMSGFORNECEDOR     = :TXMSGFORNECEDOR,
                        IDCOTUNICAPEDCOL    = :IDCOTUNICAPEDCOL,
                        IDUTLAPROVMASSA     = :IDUTLAPROVMASSA,
                        IDFILIALPADRAOSMTP  = :IDFILIALPADRAOSMTP
                    WHERE CDFILIAL = :CDFILIAL";

            $params = array(
                "DSLINKFALECONOSCO" => $row["DSLINKFALECONOSCO"],
                "DSLINKAUXILIAR"    => $row["DSLINKAUXILIAR"],
                "DSNOMELINKAUX"     => $row["DSNOMELINKAUX"],
                "DSLINKECOMMERCE"   => $row['DSLINKECOMMERCE'],
                "IDEXIBEQTDCMP"     => $row["IDEXIBEQTDCMP"],
                "CDEMPRESA"         => $row["CDEMPRESA"],
                "IDGRAVAITEMZERADO" => $row["IDGRAVAITEMZERADO"],
                "TXMSGFORNECEDOR"   => $row["TXMSGFORNECEDOR"],
                "IDCOTUNICAPEDCOL"  => $row["IDCOTUNICAPEDCOL"],
                "IDUTLAPROVMASSA"   => $row["IDUTLAPROVMASSA"],
                "IDFILIALPADRAOSMTP" => $row["IDFILIALPADRAOSMTP"],
                "CDFILIAL"          => $centralCompras
            );

            $dataSet = $this->entityManager->getConnection()->executeUpdate($sql, $params);
        }
        return $dataSet;
    }

    public function getPedidoColeta($cdForneced)
    {
        $query = $this->entityManager->getConnection()->prepare(
            "SELECT FORNECEDOR.CDFORNECED,
                FORNECEDOR.IDNPERMANCOTINT,
                FORNECEDOR.IDUTLCTRLTERMO,
                FORNECEDOR.DSEMAILPEDCOLFO,
                FORNECEDOR.DSMAILPEDCOLCOP,
                FORNECEDOR.CDSENHAFOR,
                FORNECEDOR.VRPERVARPREC,
                FORNECEDOR.CDOPERGESTOR,
                OPERADOR.NMOPERADOR AS NMOPERGESTOR,
                FORNECEDOR.NRTELSUPORTEFOR,
                FORNECEDOR.DSEMAILPGTOFOR,
                FORNECEDOR.DSEMAILAFFOR,
                FORNECEDOR.DSEMAILAFFO,
                FORNECEDOR.DSEMAILAFCOP,
                FORNECEDOR.CDSENHAAFFOR,
                FORNECEDOR.DSEMAILCRFO,
                FORNECEDOR.DSEMAILCRCOP,
                FORNECEDOR.CDSENHACRFOR,
                FORNECEDOR.CDFORNERELACAF,
                FORNECEDOR.VRPERVARDESCPREC,
                FORNECEDOR.IDUTLCONFIMATENDAF,
                FORNECEDOR.IDPERALTAFCONF,
                FORNECEDOR.DSEMAILNOTIFATENDAF,
                FORNECEDOR.DSTOKENINTGECO
            FROM FORNECEDOR LEFT JOIN OPERADOR ON FORNECEDOR.CDOPERGESTOR = OPERADOR.CDOPERADOR
            WHERE FORNECEDOR.CDFORNECED = :P_CDFORNECED"
        );

        $query->execute(
            array(
                "P_CDFORNECED" => $cdForneced
            )
        );

        $dataSet = $query->fetchAll();

        return $dataSet;
    }

    public function savePedidoColeta($row)
    {
        $sql =
            "UPDATE FORNECEDOR
                SET IDNPERMANCOTINT     = :IDNPERMANCOTINT,
                    IDUTLCTRLTERMO      = :IDUTLCTRLTERMO,
                    DSEMAILPEDCOLFO     = :DSEMAILPEDCOLFO,
                    VRPERVARPREC        = :VRPERVARPREC,
                    CDOPERGESTOR        = :CDOPERGESTOR,
                    NRTELSUPORTEFOR     = :NRTELSUPORTEFOR,
                    DSEMAILPGTOFOR      = :DSEMAILPGTOFOR,
                    DSEMAILAFFOR        = :DSEMAILAFFOR,
                    VRPERVARDESCPREC    = :VRPERVARDESCPREC,
                    IDUTLCONFIMATENDAF  = :IDUTLCONFIMATENDAF,
                    IDPERALTAFCONF      = :IDPERALTAFCONF,
                    DSEMAILNOTIFATENDAF = :DSEMAILNOTIFATENDAF 
                WHERE CDFORNECED = :CDFORNECED";
        $params = array(
            "IDNPERMANCOTINT"     => $row["IDNPERMANCOTINT"],
            "IDUTLCTRLTERMO"      => $row["IDUTLCTRLTERMO"],
            "DSEMAILPEDCOLFO"     => $row["DSEMAILPEDCOLFO"],
            "VRPERVARPREC"        => $row["VRPERVARPREC"],
            "CDOPERGESTOR"        => $row["CDOPERGESTOR"],
            "NRTELSUPORTEFOR"     => $row["NRTELSUPORTEFOR"],
            "DSEMAILPGTOFOR"      => $row["DSEMAILPGTOFOR"],
            "DSEMAILAFFOR"        => $row["DSEMAILAFFOR"],
            "VRPERVARDESCPREC"    => $row["VRPERVARDESCPREC"],
            "CDFORNECED"          => $row["CDFORNECED"],
            "IDUTLCONFIMATENDAF"  => $row["IDUTLCONFIMATENDAF"],
            "IDPERALTAFCONF"      => $row["IDPERALTAFCONF"],
            "DSEMAILNOTIFATENDAF" => $row["DSEMAILNOTIFATENDAF"]
        );

        $dataSet = $this->entityManager->getConnection()->executeUpdate($sql, $params);

        return $dataSet;
    }

    public function deleteLoginAcesso($row)
    {
        $query = $this->entityManager->getConnection()->prepare(
            "DELETE FROM DADOSFORNECOMMERCE 
                   WHERE CDFORNECED = :CDFORNECED 
                     AND DSLOGINECO = :DSLOGINECO"
        );
        $query->execute(array(
            "CDFORNECED" => $row["CDFORNECED"],
            "DSLOGINECO" => $row["DSLOGINECO"],
        ));
    }

    private function getOperadorTeknisa($row)
    {
        $query = $this->connection->prepare(
            "SELECT CDOPERADOR FROM OPERADOR WHERE CDOPERADOR LIKE '1099%' AND DSEMAILOPER = :DSLOGINECO"
        );

        $query->execute(array(
            "DSLOGINECO" => $row["DSLOGINECO"]
        ));

        return $query->fetchAll();
    }

    public function deletaInfoOperador($row)
    {
        $operadores = self::getOperadorTeknisa($row);
        if (is_array($operadores) && count($operadores)) {
            foreach ($operadores as $operador) {
                self::deleteOrganizacaooper($operador);
                self::deleteControlsenha($operador);
                self::deleteOperadoracesso($operador);
                self::deletaOrgRelacOper($operador);
                self::deleteComproper($operador);
                self::deleteOperador($operador);
            }
        }
    }

    public function deleteComproper($row)
    {
        $query = $this->entityManager->getConnection()->prepare(
            "DELETE FROM COMPROPER WHERE CDOPERADOR = :CDOPERADOR"
        );

        $query->execute(array(
            "CDOPERADOR" => $row["CDOPERADOR"]
        ));
    }

    public function verificaExclusao($row)
    {
        $query = $this->entityManager->getConnection()->prepare(
            "SELECT DSLOGINECO, CDFORNECED, CDOPERFORN
               FROM DADOSFORNECOMMERCE
              WHERE DSLOGINECO = :P_DSLOGINECO"
        );

        $query->execute(array(
            "P_DSLOGINECO" => $row["DSLOGINECO"]
        ));

        return $query->fetchAll();
    }

    public function validacoesAcesso($request, $response)
    {
        $row = $request->getRow();

        if ($row["__is_new"]) {
            $query = $this->connection->prepare(
                "SELECT DSLOGINECO FROM DADOSFORNECOMMERCE WHERE CDFORNECED = :P_CDFORNECED AND DSLOGINECO = :P_DSLOGINECO"
            );

            $query->execute(array(
                "P_CDFORNECED" => $row["CDFORNECED"],
                "P_DSLOGINECO" => $row["DSLOGINECO"]
            ));

            $dataSet = $query->fetchAll();

            if (sizeof($dataSet) > 0) {
                throw new \Exception("Login já cadastrado");
            }
        }

        if ($row["IDADMINISTRADOR"] == 'S') {
            $query = $this->connection->prepare(
                "SELECT * FROM DADOSFORNECOMMERCE WHERE CDFORNECED = :P_CDFORNECED AND IDADMINISTRADOR = 'S' AND DSLOGINECO <> :P_DSLOGINECO"
            );

            $query->execute(array(
                "P_CDFORNECED" => $row["CDFORNECED"],
                "P_DSLOGINECO" => $row["DSLOGINECO"]
            ));

            $dataSet = $query->fetchAll();

            if (sizeof($dataSet) > 0) {
                throw new \Exception("Outro login já foi cadastrado como administrador");
            }
        }

        $query = $this->connection->prepare(
            "SELECT DSLOGINECO, IDTPIJURFORN, NRINSJURFORN, NMFANTFORN, NMRAZSOCFORN, 
                    FORNECEDOR.CDFORNECED
                FROM DADOSFORNECOMMERCE, FORNECEDOR
                WHERE DADOSFORNECOMMERCE.CDFORNECED = FORNECEDOR.CDFORNECED
                    AND DADOSFORNECOMMERCE.CDFORNECED <> :P_CDFORNECED
                    AND DSLOGINECO = :P_DSLOGINECO"
        );

        $query->execute(array(
            "P_CDFORNECED" => $row["CDFORNECED"],
            "P_DSLOGINECO" => $row["DSLOGINECO"]
        ));

        $dataSet = $query->fetchAll();

        return $dataSet;
    }

    public function saveLoginRelacionado($row)
    {
        $query = $this->connection->prepare(
            "UPDATE DADOSFORNECOMMERCE SET CDSENHAWEB = :CDSENHAWEB, CDSENHA = :CDSENHA WHERE DSLOGINECO = :DSLOGINECO"
        );

        $query->execute(array(
            "CDSENHAWEB"   => $this->getWebCrypt($row["CDSENHAWEB"]),
            "CDSENHA"      => Utilities::getDelphiPasswordEncrypted($row["CDSENHAWEB"]), // $this->getDelphiCrypt($row["CDSENHAWEB"]),
            "DSLOGINECO"   => $row["DSLOGINECO"]
        ));
    }

    public function saveNovoLogin($row)
    {
        try {
            $this->beginTransaction();
            $this->geraNumOperador($row);

            $query = $this->connection->prepare(
                "INSERT INTO DADOSFORNECOMMERCE
                   (NMUSUARIOECO, CDFORNECED,     DSLOGINECO,     CDSENHAWEB,         CDSENHA,        IDACESSOCOT,
                    IDACESSOAF,     IDACESSOCR, IDACESSOUPLOAD,   IDADMINISTRADOR,    DSEMAILECO,   CDOPERFORN,     NRORG)
                VALUES 
                   (:NMUSUARIOECO, :CDFORNECED,    :DSLOGINECO,    :CDSENHAWEB,        :CDSENHA,       :IDACESSOCOT,
                    :IDACESSOAF,    :IDACESSOCR, :IDACESSOUPLOAD,    :IDADMINISTRADOR,   :DSEMAILECO,  :CDOPERFORN,   :NRORG)"
            );

            $query->execute(array(
                "NMUSUARIOECO"    => $row["NMUSUARIOECO"],
                "CDFORNECED"      => $row["CDFORNECED"],
                "DSLOGINECO"      => $row["DSLOGINECO"],
                "CDSENHAWEB"      => $this->getWebCrypt($row["CDSENHAWEB"]),
                "CDSENHA"         => Utilities::getDelphiPasswordEncrypted($row["CDSENHAWEB"]),
                "IDACESSOCOT"     => $row["IDACESSOCOT"],
                "IDACESSOAF"      => $row["IDACESSOAF"],
                "IDACESSOCR"      => $row["IDACESSOCR"],
                "IDACESSOUPLOAD"  => $row["IDACESSOUPLOAD"],
                "IDADMINISTRADOR" => $row["IDADMINISTRADOR"],
                "DSEMAILECO"      => $row["DSEMAILECO"],
                "CDOPERFORN"      => $row["CDOPERFORN"],
                "NRORG"           => $this->environment->getNrOrg()
            ));

            $cdoperador = $this->retornaOperador($row["DSLOGINECO"]);
            $operadorSistemaTeknisa = $this->verificaOperadorSistemaTeknisa($cdoperador);

            $this->commit();

            return $operadorSistemaTeknisa;
        } catch (\Exception $e) {
            $this->rollback();
            throw $e;
        }
    }

    private function verificaOperadorSistemaTeknisa($codigoOperador)
    {
        if ($codigoOperador) {
            $prefixoFornecedor = "1099";
            $prefixoOperador = substr($codigoOperador, 0, 4);

            if ($prefixoFornecedor <> $prefixoOperador) {
                return true;
            }
        }

        return false;
    }

    public function geraNumOperador($row)
    {
        $row['CDOPERFORN'] = '1099' . str_pad(mt_rand(1, 99999999), 8, '0', STR_PAD_LEFT);
    }

    public function getNmOperador($row)
    {
        $query = $this->connection->prepare(
            "SELECT 
                MAX(NMFANTFORN) AS NMFANTFORN
            FROM 
                DADOSFORNECOMMERCE D, 
                FORNECEDOR F
            WHERE 
                D.CDFORNECED = :CDFORNECED AND 
                D.CDFORNECED = F.CDFORNECED"
        );

        $query->execute(array(
            "CDFORNECED"  => $row["CDFORNECED"]
        ));

        $dados = $query->fetchAll();

        return $dados[0]['NMFANTFORN'];
    }

    public function saveEdicaoLogin($row)
    {
        try {
            $this->entityManager->beginTransaction();

            $operadorSistemaTeknisa = false;

            $params = array(
                "IDACESSOCOT"     => $row["IDACESSOCOT"],
                "IDACESSOAF"      => $row["IDACESSOAF"],
                "IDACESSOCR"      => $row["IDACESSOCR"],
                "IDACESSOUPLOAD"  => $row["IDACESSOUPLOAD"],
                "IDADMINISTRADOR" => $row["IDADMINISTRADOR"],
                "DSEMAILECO"      => $row["DSEMAILECO"],
                "DSLOGINECO"      => $row["DSLOGINECO"],
                "CDFORNECED"      => $row["CDFORNECED"],
                "NMUSUARIOECO"    => $row["NMUSUARIOECO"]
            );

            if ($row["SENHA_ALTERADA"] == "S") {
                $query = $this->connection->prepare(
                    "UPDATE DADOSFORNECOMMERCE
                    SET CDSENHAWEB      = :CDSENHAWEB,
                        CDSENHA         = :CDSENHA,
                        IDACESSOCOT     = :IDACESSOCOT,
                        IDACESSOAF      = :IDACESSOAF,
                        IDACESSOCR      = :IDACESSOCR,
                        IDACESSOUPLOAD  = :IDACESSOUPLOAD,
                        IDADMINISTRADOR = :IDADMINISTRADOR,
                        DSEMAILECO      = :DSEMAILECO,
                        NMUSUARIOECO    = :NMUSUARIOECO
                    WHERE DSLOGINECO    = :DSLOGINECO
                        AND CDFORNECED  = :CDFORNECED"
                );

                $params["CDSENHAWEB"] = $this->getWebCrypt($row["CDSENHAWEB"]);
                $params["CDSENHA"] = Utilities::getDelphiPasswordEncrypted($row["CDSENHAWEB"]);

                $query->execute($params);
            } else {
                $query = $this->connection->prepare(
                    "UPDATE DADOSFORNECOMMERCE
                    SET IDACESSOCOT     = :IDACESSOCOT,
                        IDACESSOAF      = :IDACESSOAF,
                        IDACESSOCR      = :IDACESSOCR,
                        IDACESSOUPLOAD  = :IDACESSOUPLOAD,
                        IDADMINISTRADOR = :IDADMINISTRADOR,
                        DSEMAILECO      = :DSEMAILECO,
                        NMUSUARIOECO    = :NMUSUARIOECO
                    WHERE DSLOGINECO    = :DSLOGINECO
                        AND CDFORNECED  = :CDFORNECED"
                );

                $query->execute($params);
            }

            $this->entityManager->flush();
            $this->entityManager->commit();

            return $operadorSistemaTeknisa;
        } catch (\Exception $e) {
            $this->entityManager->rollback();
            throw $e;
        }
    }

    public function deleteOperador($row)
    {
        $query = $this->entityManager->getConnection()->prepare(
            "DELETE FROM OPERADOR WHERE CDOPERADOR = :CDOPERADOR"
        );

        $query->execute(array(
            "CDOPERADOR" => $row["CDOPERADOR"]
        ));
    }

    public function deletaOrgRelacOper($row)
    {
        $query = $this->entityManager->getConnection()->prepare(
            "DELETE FROM ORGRELACOPER WHERE CDOPERADOR = :CDOPERADOR"
        );

        $query->execute(array(
            "CDOPERADOR" => $row["CDOPERADOR"]
        ));
    }

    public function deleteOrganizacaooper($row)
    {
        $query = $this->entityManager->getConnection()->prepare(
            "DELETE FROM ORGANIZACAOOPER WHERE CDOPERADOR = :CDOPERADOR"
        );

        $query->execute(array(
            "CDOPERADOR" => $row["CDOPERADOR"]
        ));
    }

    public function deleteControlsenha($row)
    {
        $query = $this->entityManager->getConnection()->prepare(
            "DELETE FROM CONTROLSENHA WHERE CDOPERADOR = :CDOPERADOR"
        );

        $query->execute(array(
            "CDOPERADOR" => $row["CDOPERADOR"]
        ));
    }

    public function deleteOperadoracesso($row)
    {
        $query = $this->entityManager->getConnection()->prepare(
            "DELETE FROM OPERADOR_ACESSO WHERE CDOPERADOR = :CDOPERADOR"
        );

        $query->execute(array(
            "CDOPERADOR" => $row["CDOPERADOR"]
        ));
    }

    public function uploadManual($row)
    {
        try {
            $this->entityManager->beginTransaction();

            $sql = "UPDATE PARAMGERALECOMMERCE
                    SET DSMANUALFILESERV = :DSMANUALFILESERV
                    WHERE CDFILIAL = :CDFILCENTCMP";

            $params = array(
                "DSMANUALFILESERV" => $row["DSMANUALFILESERV"],
                "CDFILCENTCMP" => $row["CDFILCENTCMP"]
            );

            $this->entityManager->getConnection()->executeUpdate($sql, $params);
            $this->entityManager->commit();
        } catch (\Exception $e) {
            $this->entityManager->rollback();
            throw $e;
        }
    }

    public function getManualInfo($row)
    {
        $query = $this->connection->prepare(
            "SELECT 
                DSMANUALFILESERV, CDFILIAL
            FROM 
                PARAMGERALECOMMERCE
            WHERE 
                CDFILIAL = :CDFILCENTCMP"
        );

        $query->execute(array(
            "CDFILCENTCMP"  => $row["CDFILCENTCMP"]
        ));

        $dados = $query->fetchAll();

        if (isset($dados[0]['DSMANUALFILESERV']) != isset($dados[0]['CDFILIAL'])) {
            return "";
        } else {
            return isset($dados[0]['DSMANUALFILESERV']) ? $dados[0]['DSMANUALFILESERV'] : false;
        }
    }

    public function getLogoEmail()
    {
        $query = $this->connection->prepare(
            "SELECT 
                URLLOGO
            FROM 
                APPCONFIG 
            WHERE 
                IDAPLICATIVO = 'PORTAL E-COMMERCE'
                AND NRORG = :P_NRORG"
        );

        $query->execute(array(
            "P_NRORG" => $this->environment->getNrOrgTrab()
        ));

        $result = $query->fetchAll();

        if (isset($result[0]) && array_key_exists("URLLOGO", $result[0])) {
            $data["EXIST"] = true;
            $data["URLLOGO"] = $result[0]["URLLOGO"];
        } else {
            $data["EXIST"] = false;
            $data["URLLOGO"] = null;
        }

        return $data;
    }

    public function saveLogoEmail($logo)
    {
        try {
            $result = $this->getLogoEmail();

            if ($result["EXIST"] == true) {
                $this->updateLogoEmail($logo);
            } else {
                $this->insertAppConfig($logo, ".");
            }
        } catch (\Exception $e) {
            throw $e;
        }
    }

    private function updateLogoEmail($logo)
    {
        $sql = "UPDATE 
                    APPCONFIG 
                SET
                    URLLOGO = :P_URLLOGO
                WHERE 
                    IDAPLICATIVO = 'PORTAL E-COMMERCE'
                    AND NRORG = :P_NRORG";

        $params = array(
            "P_URLLOGO" => $logo,
            "P_NRORG" => $this->environment->getNrOrgTrab()
        );

        $this->entityManager->getConnection()->executeUpdate($sql, $params);
    }

    private function insertAppConfig($logo, $dns)
    {
        $novoCodigo = (int)$this->newCodeSC->getCodeByTableName('APPCONFIG', $this->environment->getNrOrg());

        $query = $query = $this->connection->prepare(
            "INSERT INTO APPCONFIG
                (
                    NRAPPCONFIG, 
                    DSDNS, 
                    DSPORTA, 
                    IDAPLICATIVO, 
                    NRORG, 
                    IDATIVO, 
                    DTINCLUSAO,
                    URLLOGO,
                    DSCORPRIMARIA
                )
            VALUES
                (
                    :P_NRAPPCONFIG, 
                    :P_DSDNS, 
                    null, 
                    'PORTAL E-COMMERCE',
                    :P_NRORG,
                    'S',
                    SYSDATE,
                    :P_URLLOGO,
                    null
                )"
        );

        $query->execute(array(
            "P_NRAPPCONFIG" => $novoCodigo,
            "P_DSDNS" => $dns,
            "P_NRORG" => $this->environment->getNrOrgTrab(),
            "P_URLLOGO" => $logo
        ));
    }

    public function saveDNS($dns)
    {
        try {
            $result = $this->getLogoEmail();

            if ($result["EXIST"] == true) {
                $this->updateDNS($dns);
            } else {
                $this->insertAppConfig(null, $dns);
            }
        } catch (\Exception $e) {
            throw $e;
        }
    }

    private function updateDNS($dns)
    {
        $sql = "UPDATE 
                    APPCONFIG 
                SET
                    DSDNS = :P_DSDNS
                WHERE 
                    IDAPLICATIVO = 'PORTAL E-COMMERCE'
                    AND NRORG = :P_NRORG";

        $params = array(
            "P_DSDNS" => $dns,
            "P_NRORG" => $this->environment->getNrOrgTrab()
        );

        $this->entityManager->getConnection()->executeUpdate($sql, $params);
    }

    public function checkActiveCollectRequest($cdForneced)
    {
        $query = $this->connection->prepare(
            "SELECT
                PCG.NRPEDIDOCOL
            FROM
                PEDCOLGERAL PCG,
                PEDCOLETA PC
            WHERE
                PCG.NRPEDIDOCOL = PC.NRPEDIDOCOL
                AND ( PCG.IDSITUPEDCOLETA = 'T' OR PCG.IDSITUPEDCOLETA = 'C' )
                AND PC.CDFORNECED = :P_CDFORNECED
                AND PCG.NRORG = :P_NRORG
                AND PCG.DTEXPIRAPEDCOL > SYSDATE
                AND NOT EXISTS
                (
                    SELECT
                        1
                    FROM
                        ITEMCOLE IC
                    WHERE
                        IC.CDFILIAL = PCG.CDFILIAL
                        AND IC.NRPEDIDOCOL = PCG.NRPEDIDOCOL
                )"
        );

        $query->execute(array(
            "P_CDFORNECED" => $cdForneced,
            "P_NRORG" => $this->environment->getNrOrgTrab()
        ));

        return $query->fetchAll();
    }

    public function salvaChaveAcesso($fornecedor, $chaveAcesso)
    {
        $sql = "UPDATE FORNECEDOR
                   SET DSTOKENINTGECO = :CHAVE_ACESSO
                 WHERE CDFORNECED = :FORNECEDOR";

        $params = array(
            "FORNECEDOR" => $fornecedor,
            "CHAVE_ACESSO" => $chaveAcesso
        );

        $query = $this->connection->prepare($sql);

        $query->execute($params);
    }

    public function getTermoAceite()
    {
        $sql = "SELECT COUNT(FORNECEDOR.IDUTLCTRLTERMO) AS QTD_IDUTLCTRLTERMO
                    FROM FORNECEDOR WHERE IDUTLCTRLTERMO ='S' ";

        $query = $this->connection->prepare($sql);

        $query->execute();

        return $query->fetchAll();
    }

    public function retornaOperador($DSLOGINECO)
    {
        $query = $this->connection->prepare(
            "SELECT CDOPERFORN FROM DADOSFORNECOMMERCE WHERE DSLOGINECO = :DSLOGINECO"
        );

        $query->execute(array("DSLOGINECO"  => $DSLOGINECO));

        $dataSet = $query->fetchAll();
        return isset($dataSet[0]["CDOPERFORN"]) ? $dataSet[0]["CDOPERFORN"] : false;
    }

    public function retornaUnidadePadraoSMTP()
    {
        $sql = "SELECT CDFILIAL FROM PARAMGERALECOMMERCE WHERE IDFILIALPADRAOSMTP = 'S' AND NRORG = :NRORG";
        $params = [
            "NRORG" => $this->environment->getNrOrgTrab()
        ];
        $query = $this->connection->prepare($sql);
        $query->execute($params);
        $unidadepadraosmtp = $query->fetchAll();
        return isset($unidadepadraosmtp[0]['CDFILIAL']) ? $unidadepadraosmtp[0]['CDFILIAL'] : null;
    }

    public function updateUnidadePadraoSMTP()
    {
        try {
            $this->entityManager->beginTransaction();
            $sql = "UPDATE PARAMGERALECOMMERCE SET IDFILIALPADRAOSMTP = 'N' WHERE IDFILIALPADRAOSMTP = 'S' AND NRORG = :NRORG";
            $params = [
                "NRORG" => $this->environment->getNrOrgTrab()
            ];
            $this->entityManager->getConnection()->executeUpdate($sql, $params);
            $this->entityManager->commit();
        } catch (\Exception $e) {
            $this->entityManager->rollback();
            throw $e;
        }
    }
}
