<?php

namespace Services;

class FileService
{
    protected $fileUploader;
    protected $fileServerFilesUrl;

    public function __construct($fileUploader, $fileServerFilesUrl)
    {
        $this->fileUploader         = $fileUploader;
        $this->fileServerFilesUrl   = $fileServerFilesUrl;
    }

    public function getFileServerUrl()
    {
        try {
            return $this->fileServerFilesUrl;
        } catch (\Exception $e) {
            throw $e;
        }
    }

    public function deleteFile($row)
    {
        try {
            $this->fileUploader->deleteFile($row['NMPATHANEXO']);
        } catch (\Exception $e) {
            throw $e;
        }
    }

    public function uploudFile($arquivo)
    {
        try {
            if (isset($arquivo)) {
                $file = array(
                    "name" => time() . '.' . explode('/', $arquivo["type"])[1],
                    "lastModified" => $arquivo["lastModified"],
                    "lastModifiedDate" => $arquivo["lastModifiedDate"],
                    "webkitRelativePath" => $arquivo["webkitRelativePath"],
                    "type" => $arquivo["type"],
                    "size"  => $arquivo["size"],
                    "b64File" => $arquivo["b64File"]
                );

                $row['ANEXOLANCAF']    = array();
                $row['ANEXOLANCAF'][0] = $file;

                $this->fileUploader->uploadFilesInRow($row, 'ANEXOLANCAF', 'ANEXOLANCAF');

                return $row['ANEXOLANCAF'][0]['path'];
            } else {
                return false;
            }
        } catch (\Exception $e) {
            throw $e;
        }
    }

    public function downloadFile($file, $fileName)
    {
        try {
            if (isset($file)) {
                $contentLenghtArray = array();

                foreach (get_headers($file) as $value) {
                    if (strpos($value, 'Content-Length: ') !== false) {
                        array_push($contentLenghtArray, str_replace('Content-Length: ', '', $value));
                    }
                };

                $contentLenght = max($contentLenghtArray);

                $key = $this->hasErrorOnResponse(get_headers($file));

                if (is_numeric($key)) {
                    throw new \Exception(get_headers($file)[$key]);
                }

                $tipo = null;

                switch (strtolower(substr(strrchr(basename($file), "."), 1))) {
                    case "gif":
                        $tipo = "image/gif";
                        break;
                    case "png":
                        $tipo = "image/png";
                        break;
                    case "jpg":
                        $tipo = "image/jpg";
                        break;
                    case "wma":
                        $tipo = "audio/mime";
                        break;
                    case "txt":
                        $tipo = "text/plain";
                        break;
                    case "rem":
                        $tipo = "text/plain";
                        break;
                    case "mp3":
                        $tipo = "audio/mpeg";
                        break;
                    case "mp4":
                        $tipo = "video/mpeg-4";
                        break;
                    case "pdf":
                        $tipo = "application/pdf";
                        break;
                    case "zip":
                        $tipo = "application/zip";
                        break;
                    case "doc":
                        $tipo = "application/msword";
                        break;
                    case "xls":
                        $tipo = "application/vnd.ms-excel";
                        break;
                    case "exe":
                        $tipo = "application/octet-stream";
                        break;
                    case "ppt":
                        $tipo = "application/vnd.ms-powerpoint";
                        break;
                    case "php":;
                        break;
                    case "htm":;
                        break;
                    case "html":;
                        break;
                }

                header("Content-Type: " . $tipo);
                header("Content-Length: " . $contentLenght);
                header("Content-Disposition: attachment; filename=" . basename($fileName));

                readfile($file);

                die();
            } else {
                throw new \Exception('URL não definida.');
            }
        } catch (\Exception $e) {
            throw $e;
        }
    }

    public function hasErrorOnResponse($headers)
    {
        $errors = [
            'HTTP/1.1 404 Not Found',
            'HTTP/1.1 500 Internal Server Error',
        ];

        foreach ($errors as $error) {
            $key = array_search($error, $headers);

            if (is_numeric($key)) {
                return $key;
            }
        }

        return false;
    }
}
